@@ -1,10 +1,7 @@
 #!/usr/bin/env python
 
-# Execute with
-# $ python youtube_dl/__main__.py (2.6+)
-# $ python -m youtube_dl          (2.7+)
-
 import sys
+from gdrv.main import main
 
 if __package__ is None and not hasattr(sys, "frozen"):
     # direct call of __main__.py
@@ -12,7 +9,6 @@ if __package__ is None and not hasattr(sys, "frozen"):
     path = os.path.realpath(os.path.abspath(__file__))
     sys.path.append(os.path.dirname(os.path.dirname(path)))
 
-import gdrv
 
 if __name__ == '__main__':
-    gdrv.main.main()
+    main()
