@@ -9,10 +9,9 @@ import logging
 import colorama
 import ConfigParser
 
-import global_mod as gm
-from gdrv import command_init, command_list, command_share, command_url
-from gdrv import command_push, command_pull, command_mkdir
-from gdrv import command_search, command_trash
+from gdrv import global_mod as gm
+from gdrv.commands import *
+
 
 reload(sys)
 sys.setdefaultencoding('utf-8')
@@ -38,7 +37,7 @@ def set_logging_level(plevel=0):
             logging.WARNING,
             logging.INFO,
             logging.DEBUG]
-    #print min(plevel, len(lvls) - 1)
+    # print min(plevel, len(lvls) - 1)
     lg.setLevel(lvls[min(plevel, len(lvls) - 1)])
 
 
@@ -56,13 +55,13 @@ def load_default_config():
 def get_config(args=None):
     load_default_config()
 
-    ## YMK TODO: -f filename and -w filename
+    # ## YMK TODO: -f filename and -w filename
     lg.debug("YMK dump config api ")
     lg.debug(gm.config.items('api'))
     last_cfg_name = ""
     for cfg_path in gm.config_paths:
         cfg_name = os.path.expanduser(cfg_path + '.' + gm.app_name + 'rc')
-        #lg.debug("YMK config file check %s", cfg_name)
+        # lg.debug("YMK config file check %s", cfg_name)
         if os.path.exists(cfg_name):
             last_cfg_name = cfg_name
             gm.config.read(cfg_name)
@@ -91,24 +90,35 @@ def main():
     subparser = parser.add_subparsers(help='drive sub command',
                                       dest='command_name')
 
-    drive_commands = {'list': command_list.CommandList(subparser),
-                      'push': command_push.CommandPush(subparser),
-                      'pull': command_pull.CommandPull(subparser),
-                      'mkdir': command_mkdir.CommandMkdir(subparser),
-                      'search': command_search.CommandSearch(subparser),
-                      'trash': command_trash.CommandTrash(subparser),
-                      'url': command_url.CommandUrl(subparser),
-                      'share': command_share.CommandShare(subparser),
-                      'init': command_init.CommandInit(subparser)}
+    subparser.add_parser('ftp', help='interactive mode like sftp, lftp')
+
+    # ## YMK TODO: should use factory pattern
+    drive_command_classes = {'list': CommandList,
+                             'push': CommandPush,
+                             'pull': CommandPull,
+                             'mkdir': CommandMkdir,
+                             'search': CommandSearch,
+                             'trash': CommandTrash,
+                             'url': CommandUrl,
+                             'share': CommandShare,
+                             'init': CommandInit}
+    map(lambda (k, ac): ac.static_add_sub_command_parser(subparser),
+        drive_command_classes.iteritems())
 
     args = parser.parse_args()
     set_logging_level(args.verbose)
 
     get_config(args)
 
-    colorama.init()
-    drive_commands[args.command_name].do_command(args)
-    colorama.deinit()
+    drive_commands = dict((val, drive_command_classes[val](gm.config))
+                          for (key, val) in enumerate(drive_command_classes))
+
+    if args.command_name == 'ftp':
+        print("YMK args.command_name {0}".format(args.command_name))
+    else:
+        colorama.init()
+        drive_commands[args.command_name](args)
+        colorama.deinit()
 
 
 if __name__ == '__main__':
